import { CompilerOptions } from 'typescript';
import { Logger } from './logger';
import { ResolveOptions } from './options';
/**
 * Result of dependencies resolution.
 * @internal
 */
export interface Resolution {
    /**
     * path of cause module
     */
    context: string;
    /**
     * required dependency
     */
    target: string;
    /**
     * path to resolved module
     */
    resolution: string;
    /**
     * it is a absolute url
     */
    isUrl?: boolean;
    /**
     * is resolved by the typescript
     */
    isTypescript?: boolean;
    /**
     * is resolved by the node resolver
     */
    isNode?: boolean;
}
/**
 * Base resolver type.
 */
export declare type Resolver = (context: string, target: string) => Resolution;
/**
 * Create the dependencies resolver;
 * @internal
 * @param cwd - working dir
 * @param compilerOptions - compiler options
 * @param options - resolver options
 * @param logger - logger
 */
export declare function createResolver(cwd: string, compilerOptions: CompilerOptions, options: Partial<ResolveOptions>, logger: Logger): Resolver;
//# sourceMappingURL=create-resolver.d.ts.map